@@ -87,15 +87,6 @@ Attributes:
     def actual_high(self):
         return self._actual_high
 
-    def adjust_coding(new_low, new_high, keep_actuals=True):
-        """Changes the mapping of the actual low and high to the coded low and high.
-
-        If `keep_actuals` is True, the actual observed values are preserved and the internal
-        coded values are adjusted. Otherwise, the internal coded values are preserved, and
-        the actual observed values are adjusted accordingly. """
-
-        pass
-
     @property
     def values(self):
         """Get or set the factor values. When setting the factor values, you may use
