@@ -1,7 +1,7 @@
 from enum import Enum, auto
 
 class RowStatus(Enum):
-    """An enumeration representing the different statuses rwos can have."""
+    """An enumeration representing the different statuses rows can have."""
 
     NORMAL = auto()
     IGNORED = auto()
